Struct amazon_sp_feeds::models::get_feeds_response::GetFeedsResponse
source · [−]pub struct GetFeedsResponse {
pub payload: Option<Vec<Feed>>,
pub next_token: Option<String>,
pub errors: Option<Vec<Error>>,
}Expand description
GetFeedsResponse : Response schema.
Fields
payload: Option<Vec<Feed>>next_token: Option<String>Returned when the number of results exceeds pageSize. To get the next page of results, call the getFeeds operation with this token as the only parameter.
errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
sourceimpl GetFeedsResponse
impl GetFeedsResponse
sourcepub fn new() -> GetFeedsResponse
pub fn new() -> GetFeedsResponse
Response schema.